DynamicOffset class

Constructors

DynamicOffset(Length dx, Length dy)
Constructs an elliptical radius with the given radii.
const

Properties

dx → Length
The radius value on the horizontal axis.
final
dy → Length
The radius value on the vertical axis.
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Length? dx, Length? dy}) → DynamicOffset
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toOffset({Size? size, Size? screenSize}) → Offset
toString() → String
A string representation of this object.
inherited

Operators

operator ==(dynamic other) → bool
The equality operator.
override

Constants

zero → const DynamicOffset